pub struct Config {
pub capacity: usize,
pub each: usize,
}Expand description
How large a roster this process will hold, and how large one contribution may be.
Fields
capacity: usizeHow many distinct actors may be in the roster at once.
each: usizeHow many bytes one actor’s contribution may render to.