pub async fn bind(addr: SocketAddr) -> Result<TcpListener>Expand description
The port the local listener actually bound, for tests that ask for port 0.
pub async fn bind(addr: SocketAddr) -> Result<TcpListener>The port the local listener actually bound, for tests that ask for port 0.