pub struct Case {
pub name: Arc<str>,
pub outcome: Outcome,
pub stubbed: Vec<Stubbed>,
pub runs: u64,
}Fields
name: Arc<str>outcome: Outcomestubbed: Vec<Stubbed>What 21.3 rule 1’s hidden default did, so it is not hidden: every definition that was stubbed, the atom that caused it, the value it returned and how often it was called.
runs: u64Inputs actually run, for a property.